==> 0.0.56.tar.gz: lib/common/values/sizes.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class Sizes {
  static height(BuildContext context) {
    return MediaQuery.of(context).size.height;
  }

  static width(BuildContext context) {
    return MediaQuery.of(context).size.width;
  }

  static pading(BuildContext context) {
    return MediaQuery.of(context).padding;
  }

  static padingTop(BuildContext context) {
    return MediaQuery.of(context).padding.top;
  }

  //TextSizes
  static double TEXT_SIZE_96 = 96.sp;
  static double TEXT_SIZE_60 = 60.sp;
  static double TEXT_SIZE_50 = 50.sp;
  static double TEXT_SIZE_48 = 48.sp;
  static double TEXT_SIZE_44 = 44.sp;
  static double TEXT_SIZE_40 = 40.sp;
  static double TEXT_SIZE_36 = 36.sp;
  static double TEXT_SIZE_34 = 34.sp;
  static double TEXT_SIZE_32 = 32.sp;
  static double TEXT_SIZE_30 = 30.sp;
  static double TEXT_SIZE_28 = 28.sp;
  static double TEXT_SIZE_26 = 26.sp;
  static double TEXT_SIZE_24 = 24.sp;
  static double TEXT_SIZE_22 = 22.sp;
  static double TEXT_SIZE_21 = 21.sp;
  static double TEXT_SIZE_20 = 20.sp;
  static double TEXT_SIZE_19 = 19.sp;
  static double TEXT_SIZE_18 = 18.sp;
  static double TEXT_SIZE_17 = 17.sp;
  static double TEXT_SIZE_16 = 16.sp;
  static double TEXT_SIZE_15 = 15.sp;
  static double TEXT_SIZE_14 = 14.sp;
  static double TEXT_SIZE_13 = 13.sp;
  static double TEXT_SIZE_12 = 12.sp;
  static double TEXT_SIZE_11 = 11.sp;
  static double TEXT_SIZE_10 = 10.sp;
  static double TEXT_SIZE_9 = 9.sp;
  static double TEXT_SIZE_8 = 8.sp;

  //IconSizes
  static double ICON_SIZE_50 = 50.sp;
  static double ICON_SIZE_40 = 40.sp;
  static double ICON_SIZE_32 = 32.sp;
  static double ICON_SIZE_30 = 30.sp;
  static double ICON_SIZE_24 = 24.sp;
  static double ICON_SIZE_22 = 22.sp;
  static double ICON_SIZE_20 = 20.sp;
  static double ICON_SIZE_18 = 18.sp;
  static double ICON_SIZE_16 = 16.sp;
  static double ICON_SIZE_14 = 14.sp;
  static double ICON_SIZE_12 = 12.sp;
  static double ICON_SIZE_10 = 10.sp;
  static double ICON_SIZE_8 = 8.sp;

  //Heights
  static double HEIGHT_620 = 620.h;
  static double HEIGHT_584 = 584.h;
  static double HEIGHT_580 = 580.h;
  static double HEIGHT_560 = 560.h;
  static double HEIGHT_540 = 540.h;
  static double HEIGHT_510 = 510.h;
  static double HEIGHT_506 = 506.h;
  static double HEIGHT_502 = 502.h;
  static double HEIGHT_500 = 500.h;
  static double HEIGHT_492 = 492.h;
  static double HEIGHT_460 = 460.h;
  static double HEIGHT_420 = 420.h;
  static double HEIGHT_360 = 360.h;
  static double HEIGHT_340 = 340.h;
  static double HEIGHT_320 = 320.h;
  static double HEIGHT_300 = 300.h;
  static double HEIGHT_280 = 280.h;
  static double HEIGHT_270 = 270.h;
  static double HEIGHT_268 = 268.h;
  static double HEIGHT_264 = 264.h;
  static double HEIGHT_260 = 260.h;
  static double HEIGHT_256 = 256.h;
  static double HEIGHT_250 = 250.h;
  static double HEIGHT_246 = 246.h;
  static double HEIGHT_244 = 244.h;
  static double HEIGHT_240 = 240.h;
  static double HEIGHT_230 = 230.h;
  static double HEIGHT_220 = 220.h;
  static double HEIGHT_200 = 200.h;
  static double HEIGHT_180 = 180.h;
  static double HEIGHT_160 = 160.h;
  static double HEIGHT_152 = 152.h;
  static double HEIGHT_150 = 150.h;
  static double HEIGHT_148 = 148.h;
  static double HEIGHT_146 = 146.h;
  static double HEIGHT_142 = 142.h;
  static double HEIGHT_140 = 140.h;
  static double HEIGHT_134 = 134.h;
  static double HEIGHT_136 = 136.h;
  static double HEIGHT_130 = 130.h;
  static double HEIGHT_126 = 126.h;
  static double HEIGHT_124 = 124.h;
  static double HEIGHT_120 = 120.h;
  static double HEIGHT_112 = 112.h;
  static double HEIGHT_110 = 110.h;
  static double HEIGHT_100 = 100.h;
  static double HEIGHT_98 = 98.h;
  static double HEIGHT_96 = 96.h;
  static double HEIGHT_94 = 94.h;
  static double HEIGHT_92 = 92.h;
  static double HEIGHT_90 = 90.h;
  static double HEIGHT_88 = 88.h;
  static double HEIGHT_86 = 86.h;
  static double HEIGHT_84 = 84.h;
  static double HEIGHT_82 = 82.h;
  static double HEIGHT_80 = 80.h;
  static double HEIGHT_78 = 78.h;
  static double HEIGHT_76 = 76.h;
  static double HEIGHT_74 = 74.h;
  static double HEIGHT_72 = 72.h;
  static double HEIGHT_70 = 70.h;
  static double HEIGHT_68 = 68.h;
  static double HEIGHT_66 = 66.h;
  static double HEIGHT_64 = 64.h;
  static double HEIGHT_62 = 62.h;
  static double HEIGHT_60 = 60.h;
  static double HEIGHT_58 = 58.h;
  static double HEIGHT_56 = 56.h;
  static double HEIGHT_54 = 54.h;
  static double HEIGHT_52 = 52.h;
  static double HEIGHT_50 = 50.h;
  static double HEIGHT_48 = 48.h;
  static double HEIGHT_46 = 46.h;
  static double HEIGHT_44 = 44.h;
  static double HEIGHT_40 = 40.h;
  static double HEIGHT_42 = 42.h;
  static double HEIGHT_36 = 36.h;
  static double HEIGHT_38 = 38.h;
  static double HEIGHT_32 = 32.h;
  static double HEIGHT_30 = 30.h;
  static double HEIGHT_28 = 28.h;
  static double HEIGHT_26 = 26.h;
  static double HEIGHT_24 = 24.h;
  static double HEIGHT_22 = 22.h;
  static double HEIGHT_20 = 20.h;
  static double HEIGHT_18 = 18.h;
  static double HEIGHT_16 = 16.h;
  static double HEIGHT_14 = 14.h;
  static double HEIGHT_10 = 10.h;
  static double HEIGHT_12 = 12.h;
  static double HEIGHT_8 = 8.h;
  static double HEIGHT_6 = 6.h;
  static double HEIGHT_4 = 4.h;
  static double HEIGHT_3 = 3.h;
  static double HEIGHT_2 = 2.h;
  static double HEIGHT_1 = 1.h;

  //Widths
  static double WIDTH_300 = 300.w;
  static double WIDTH_250 = 250.w;
  static double WIDTH_240 = 240.w;
  static double WIDTH_236 = 236.w;
  static double WIDTH_220 = 220.w;
  static double WIDTH_200 = 200.w;
  static double WIDTH_180 = 180.w;
  static double WIDTH_170 = 170.w;
  static double WIDTH_160 = 160.w;
  static double WIDTH_150 = 150.w;
  static double WIDTH_126 = 126.w;
  static double WIDTH_120 = 120.w;
  static double WIDTH_110 = 110.w;
  static double WIDTH_108 = 180.w;
  static double WIDTH_106 = 160.w;
  static double WIDTH_104 = 160.w;
  static double WIDTH_102 = 120.w;
  static double WIDTH_100 = 100.w;
  static double WIDTH_90 = 90.w;
  static double WIDTH_80 = 80.w;
  static double WIDTH_78 = 78.w;
  static double WIDTH_68 = 68.w;
  static double WIDTH_64 = 64.w;
  static double WIDTH_60 = 60.w;
  static double WIDTH_50 = 50.w;
  static double WIDTH_52 = 52.w;
  static double WIDTH_54 = 54.w;
  static double WIDTH_58 = 58.w;
  static double WIDTH_56 = 56.w;
  static double WIDTH_48 = 48.w;
  static double WIDTH_46 = 46.w;
  static double WIDTH_40 = 40.w;
  static double WIDTH_36 = 36.w;
  static double WIDTH_34 = 34.w;
  static double WIDTH_32 = 32.w;
  static double WIDTH_30 = 30.w;
  static double WIDTH_26 = 26.w;
  static double WIDTH_24 = 24.w;
  static double WIDTH_22 = 22.w;
  static double WIDTH_20 = 20.w;
  static double WIDTH_18 = 18.w;
  static double WIDTH_16 = 16.w;
  static double WIDTH_14 = 14.w;
  static double WIDTH_12 = 12.w;
  static double WIDTH_10 = 10.w;
  static double WIDTH_8 = 8.w;
  static double WIDTH_6 = 6.w;
  static double WIDTH_4 = 4.w;
  static double WIDTH_2 = 2.w;
  static double WIDTH_1 = 1.w;
  static double WIDTH_0 = 0.w;

  //Margins
  static double MARGIN_200 = 200.w;
  static double MARGIN_60 = 60.w;
  static double MARGIN_48 = 48.w;
  static double MARGIN_46 = 46.w;
  static double MARGIN_44 = 44.w;
  static double MARGIN_40 = 40.w;
  static double MARGIN_36 = 36.w;
  static double MARGIN_32 = 32.w;
  static double MARGIN_30 = 30.w;
  static double MARGIN_26 = 26.w;
  static double MARGIN_24 = 24.w;
  static double MARGIN_22 = 22.w;
  static double MARGIN_20 = 20.w;
  static double MARGIN_18 = 18.w;
  static double MARGIN_16 = 16.w;
  static double MARGIN_14 = 14.w;
  static double MARGIN_12 = 12.w;
  static double MARGIN_10 = 10.w;
  static double MARGIN_8 = 8.w;
  static double MARGIN_6 = 6.w;
  static double MARGIN_4 = 4.w;
  static double MARGIN_0 = 0.w;

  //Paddings
  static double PADDING_40 = 40.w;
  static double PADDING_36 = 36.w;
  static double PADDING_32 = 32.w;
  static double PADDING_24 = 24.w;
  static double PADDING_22 = 22.w;
  static double PADDING_20 = 20.w;
  static double PADDING_18 = 18.w;
  static double PADDING_16 = 16.w;
  static double PADDING_14 = 14.w;
  static double PADDING_12 = 12.w;
  static double PADDING_10 = 10.w;
  static double PADDING_8 = 8.w;
  static double PADDING_6 = 6.w;
  static double PADDING_4 = 4.w;
  static double PADDING_2 = 2.w;
  static double PADDING_0 = 0.w;

  //Radius
  static double RADIUS_80 = 80.r;
  static double RADIUS_70 = 70.r;
  static double RADIUS_60 = 60.r;
  static double RADIUS_40 = 40.r;
  static double RADIUS_32 = 32.r;
  static double RADIUS_30 = 30.r;
  static double RADIUS_24 = 24.r;
  static double RADIUS_22 = 22.r;
  static double RADIUS_20 = 20.r;
  static double RADIUS_18 = 18.r;
  static double RADIUS_16 = 16.r;
  static double RADIUS_14 = 14.r;
  static double RADIUS_12 = 12.r;
  static double RADIUS_10 = 10.r;
  static double RADIUS_8 = 8.r;
  static double RADIUS_6 = 6.r;
  static double RADIUS_4 = 4.r;
  static double RADIUS_0 = 0.r;

  //Elevations
  static double ELEVATION_16 = 16.0;
  static double ELEVATION_14 = 14.0;
  static double ELEVATION_12 = 12.0;
  static double ELEVATION_10 = 10.0;
  static double ELEVATION_8 = 8.0;
  static double ELEVATION_6 = 6.0;
  static double ELEVATION_4 = 4.0;
  static double ELEVATION_2 = 2.0;
  static double ELEVATION_1 = 1.0;
  static double ELEVATION_0 = 0.0;

  //Margin
  static double MARGIN_HORIZONAL = 12.w;
  static double MARGIN_VERTICAL = 12.h;
  static double MARGIN_LEFT = 12.w;
  static double MARGIN_RIGHT = 12.w;
  static double MARGIN_TOP = 12.h;
  static double MARGIN_BOTTOM = 12.h;
}

==> 0.0.58.tar.gz: lib/common/values/sizes.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';

class Sizes {
  static height(BuildContext context) {
    // return MediaQuery.of(context).size.height;
    return ScreenUtil().screenHeight;
  }

  static width(BuildContext context) {
    // return MediaQuery.of(context).size.width;
    return ScreenUtil().screenWidth;
  }

  static pading(BuildContext context) {
    return MediaQuery.of(context).padding;
  }

  static padingTop(BuildContext context) {
    return MediaQuery.of(context).padding.top;
  }

  //TextSizes
  static double TEXT_SIZE_96 = 96.sp;
  static double TEXT_SIZE_60 = 60.sp;
  static double TEXT_SIZE_50 = 50.sp;
  static double TEXT_SIZE_48 = 48.sp;
  static double TEXT_SIZE_44 = 44.sp;
  static double TEXT_SIZE_40 = 40.sp;
  static double TEXT_SIZE_36 = 36.sp;
  static double TEXT_SIZE_34 = 34.sp;
  static double TEXT_SIZE_32 = 32.sp;
  static double TEXT_SIZE_30 = 30.sp;
  static double TEXT_SIZE_28 = 28.sp;
  static double TEXT_SIZE_26 = 26.sp;
  static double TEXT_SIZE_24 = 24.sp;
  static double TEXT_SIZE_22 = 22.sp;
  static double TEXT_SIZE_21 = 21.sp;
  static double TEXT_SIZE_20 = 20.sp;
  static double TEXT_SIZE_19 = 19.sp;
  static double TEXT_SIZE_18 = 18.sp;
  static double TEXT_SIZE_17 = 17.sp;
  static double TEXT_SIZE_16 = 16.sp;
  static double TEXT_SIZE_15 = 15.sp;
  static double TEXT_SIZE_14 = 14.sp;
  static double TEXT_SIZE_13 = 13.sp;
  static double TEXT_SIZE_12 = 12.sp;
  static double TEXT_SIZE_11 = 11.sp;
  static double TEXT_SIZE_10 = 10.sp;
  static double TEXT_SIZE_9 = 9.sp;
  static double TEXT_SIZE_8 = 8.sp;

  //IconSizes
  static double ICON_SIZE_50 = 50.sp;
  static double ICON_SIZE_40 = 40.sp;
  static double ICON_SIZE_32 = 32.sp;
  static double ICON_SIZE_30 = 30.sp;
  static double ICON_SIZE_24 = 24.sp;
  static double ICON_SIZE_22 = 22.sp;
  static double ICON_SIZE_20 = 20.sp;
  static double ICON_SIZE_18 = 18.sp;
  static double ICON_SIZE_16 = 16.sp;
  static double ICON_SIZE_14 = 14.sp;
  static double ICON_SIZE_12 = 12.sp;
  static double ICON_SIZE_10 = 10.sp;
  static double ICON_SIZE_8 = 8.sp;

  //Heights
  static double HEIGHT_620 = 620.h;
  static double HEIGHT_584 = 584.h;
  static double HEIGHT_580 = 580.h;
  static double HEIGHT_560 = 560.h;
  static double HEIGHT_540 = 540.h;
  static double HEIGHT_510 = 510.h;
  static double HEIGHT_506 = 506.h;
  static double HEIGHT_502 = 502.h;
  static double HEIGHT_500 = 500.h;
  static double HEIGHT_492 = 492.h;
  static double HEIGHT_460 = 460.h;
  static double HEIGHT_420 = 420.h;
  static double HEIGHT_360 = 360.h;
  static double HEIGHT_340 = 340.h;
  static double HEIGHT_320 = 320.h;
  static double HEIGHT_300 = 300.h;
  static double HEIGHT_280 = 280.h;
  static double HEIGHT_270 = 270.h;
  static double HEIGHT_268 = 268.h;
  static double HEIGHT_264 = 264.h;
  static double HEIGHT_260 = 260.h;
  static double HEIGHT_256 = 256.h;
  static double HEIGHT_250 = 250.h;
  static double HEIGHT_246 = 246.h;
  static double HEIGHT_244 = 244.h;
  static double HEIGHT_240 = 240.h;
  static double HEIGHT_230 = 230.h;
  static double HEIGHT_220 = 220.h;
  static double HEIGHT_200 = 200.h;
  static double HEIGHT_180 = 180.h;
  static double HEIGHT_160 = 160.h;
  static double HEIGHT_152 = 152.h;
  static double HEIGHT_150 = 150.h;
  static double HEIGHT_148 = 148.h;
  static double HEIGHT_146 = 146.h;
  static double HEIGHT_142 = 142.h;
  static double HEIGHT_140 = 140.h;
  static double HEIGHT_134 = 134.h;
  static double HEIGHT_136 = 136.h;
  static double HEIGHT_130 = 130.h;
  static double HEIGHT_126 = 126.h;
  static double HEIGHT_124 = 124.h;
  static double HEIGHT_120 = 120.h;
  static double HEIGHT_112 = 112.h;
  static double HEIGHT_110 = 110.h;
  static double HEIGHT_100 = 100.h;
  static double HEIGHT_98 = 98.h;
  static double HEIGHT_96 = 96.h;
  static double HEIGHT_94 = 94.h;
  static double HEIGHT_92 = 92.h;
  static double HEIGHT_90 = 90.h;
  static double HEIGHT_88 = 88.h;
  static double HEIGHT_86 = 86.h;
  static double HEIGHT_84 = 84.h;
  static double HEIGHT_82 = 82.h;
  static double HEIGHT_80 = 80.h;
  static double HEIGHT_78 = 78.h;
  static double HEIGHT_76 = 76.h;
  static double HEIGHT_74 = 74.h;
  static double HEIGHT_72 = 72.h;
  static double HEIGHT_70 = 70.h;
  static double HEIGHT_68 = 68.h;
  static double HEIGHT_66 = 66.h;
  static double HEIGHT_64 = 64.h;
  static double HEIGHT_62 = 62.h;
  static double HEIGHT_60 = 60.h;
  static double HEIGHT_58 = 58.h;
  static double HEIGHT_56 = 56.h;
  static double HEIGHT_54 = 54.h;
  static double HEIGHT_52 = 52.h;
  static double HEIGHT_50 = 50.h;
  static double HEIGHT_48 = 48.h;
  static double HEIGHT_46 = 46.h;
  static double HEIGHT_44 = 44.h;
  static double HEIGHT_40 = 40.h;
  static double HEIGHT_42 = 42.h;
  static double HEIGHT_36 = 36.h;
  static double HEIGHT_38 = 38.h;
  static double HEIGHT_32 = 32.h;
  static double HEIGHT_30 = 30.h;
  static double HEIGHT_28 = 28.h;
  static double HEIGHT_26 = 26.h;
  static double HEIGHT_24 = 24.h;
  static double HEIGHT_22 = 22.h;
  static double HEIGHT_20 = 20.h;
  static double HEIGHT_18 = 18.h;
  static double HEIGHT_16 = 16.h;
  static double HEIGHT_14 = 14.h;
  static double HEIGHT_10 = 10.h;
  static double HEIGHT_12 = 12.h;
  static double HEIGHT_8 = 8.h;
  static double HEIGHT_6 = 6.h;
  static double HEIGHT_4 = 4.h;
  static double HEIGHT_3 = 3.h;
  static double HEIGHT_2 = 2.h;
  static double HEIGHT_1 = 1.h;

  //Widths
  static double WIDTH_300 = 300.w;
  static double WIDTH_250 = 250.w;
  static double WIDTH_240 = 240.w;
  static double WIDTH_236 = 236.w;
  static double WIDTH_220 = 220.w;
  static double WIDTH_200 = 200.w;
  static double WIDTH_180 = 180.w;
  static double WIDTH_170 = 170.w;
  static double WIDTH_160 = 160.w;
  static double WIDTH_150 = 150.w;
  static double WIDTH_126 = 126.w;
  static double WIDTH_120 = 120.w;
  static double WIDTH_110 = 110.w;
  static double WIDTH_108 = 180.w;
  static double WIDTH_106 = 160.w;
  static double WIDTH_104 = 160.w;
  static double WIDTH_102 = 120.w;
  static double WIDTH_100 = 100.w;
  static double WIDTH_90 = 90.w;
  static double WIDTH_80 = 80.w;
  static double WIDTH_78 = 78.w;
  static double WIDTH_68 = 68.w;
  static double WIDTH_64 = 64.w;
  static double WIDTH_60 = 60.w;
  static double WIDTH_50 = 50.w;
  static double WIDTH_52 = 52.w;
  static double WIDTH_54 = 54.w;
  static double WIDTH_58 = 58.w;
  static double WIDTH_56 = 56.w;
  static double WIDTH_48 = 48.w;
  static double WIDTH_46 = 46.w;
  static double WIDTH_40 = 40.w;
  static double WIDTH_36 = 36.w;
  static double WIDTH_34 = 34.w;
  static double WIDTH_32 = 32.w;
  static double WIDTH_30 = 30.w;
  static double WIDTH_26 = 26.w;
  static double WIDTH_24 = 24.w;
  static double WIDTH_22 = 22.w;
  static double WIDTH_20 = 20.w;
  static double WIDTH_18 = 18.w;
  static double WIDTH_16 = 16.w;
  static double WIDTH_14 = 14.w;
  static double WIDTH_12 = 12.w;
  static double WIDTH_10 = 10.w;
  static double WIDTH_8 = 8.w;
  static double WIDTH_6 = 6.w;
  static double WIDTH_4 = 4.w;
  static double WIDTH_2 = 2.w;
  static double WIDTH_1 = 1.w;
  static double WIDTH_0 = 0.w;

  //Margins
  static double MARGIN_200 = 200.w;
  static double MARGIN_60 = 60.w;
  static double MARGIN_48 = 48.w;
  static double MARGIN_46 = 46.w;
  static double MARGIN_44 = 44.w;
  static double MARGIN_40 = 40.w;
  static double MARGIN_36 = 36.w;
  static double MARGIN_32 = 32.w;
  static double MARGIN_30 = 30.w;
  static double MARGIN_26 = 26.w;
  static double MARGIN_24 = 24.w;
  static double MARGIN_22 = 22.w;
  static double MARGIN_20 = 20.w;
  static double MARGIN_18 = 18.w;
  static double MARGIN_16 = 16.w;
  static double MARGIN_14 = 14.w;
  static double MARGIN_12 = 12.w;
  static double MARGIN_10 = 10.w;
  static double MARGIN_8 = 8.w;
  static double MARGIN_6 = 6.w;
  static double MARGIN_4 = 4.w;
  static double MARGIN_0 = 0.w;

  //Paddings
  static double PADDING_40 = 40.w;
  static double PADDING_36 = 36.w;
  static double PADDING_32 = 32.w;
  static double PADDING_24 = 24.w;
  static double PADDING_22 = 22.w;
  static double PADDING_20 = 20.w;
  static double PADDING_18 = 18.w;
  static double PADDING_16 = 16.w;
  static double PADDING_14 = 14.w;
  static double PADDING_12 = 12.w;
  static double PADDING_10 = 10.w;
  static double PADDING_8 = 8.w;
  static double PADDING_6 = 6.w;
  static double PADDING_4 = 4.w;
  static double PADDING_2 = 2.w;
  static double PADDING_0 = 0.w;

  //Radius
  static double RADIUS_80 = 80.r;
  static double RADIUS_70 = 70.r;
  static double RADIUS_60 = 60.r;
  static double RADIUS_40 = 40.r;
  static double RADIUS_32 = 32.r;
  static double RADIUS_30 = 30.r;
  static double RADIUS_24 = 24.r;
  static double RADIUS_22 = 22.r;
  static double RADIUS_20 = 20.r;
  static double RADIUS_18 = 18.r;
  static double RADIUS_16 = 16.r;
  static double RADIUS_14 = 14.r;
  static double RADIUS_12 = 12.r;
  static double RADIUS_10 = 10.r;
  static double RADIUS_8 = 8.r;
  static double RADIUS_6 = 6.r;
  static double RADIUS_4 = 4.r;
  static double RADIUS_0 = 0.r;

  //Elevations
  static double ELEVATION_16 = 16.0;
  static double ELEVATION_14 = 14.0;
  static double ELEVATION_12 = 12.0;
  static double ELEVATION_10 = 10.0;
  static double ELEVATION_8 = 8.0;
  static double ELEVATION_6 = 6.0;
  static double ELEVATION_4 = 4.0;
  static double ELEVATION_2 = 2.0;
  static double ELEVATION_1 = 1.0;
  static double ELEVATION_0 = 0.0;

  //Margin
  static double MARGIN_HORIZONAL = 12.w;
  static double MARGIN_VERTICAL = 12.h;
  static double MARGIN_LEFT = 12.w;
  static double MARGIN_RIGHT = 12.w;
  static double MARGIN_TOP = 12.h;
  static double MARGIN_BOTTOM = 12.h;
}
